@@ -59,7 +59,8 @@ class Wsdl(WsdlBase):
         'native_error': (VariableError, DistributiveError,
                          DataVarsError, install.InstallError),
         # значения по умолчанию для переменных этого метода
-        'setvars': {'cl_action!': 'system', 'cl_dispatch_conf': 'usenew'},
+        'setvars': {'cl_action!': 'system', 'cl_install_type': 'hdd',
+                    'cl_dispatch_conf': 'usenew'},
         # описание груп (список лямбда функций)
         'groups': [
             lambda group: group(_("Language and locale"),
@@ -93,7 +94,6 @@ class Wsdl(WsdlBase):
                                              'os_install_bootloader'),
                                 brief=('os_install_uefi_brief_set',),
                                 expert=('cl_uuid_set',
-                                        'os_install_root_type',
                                         'os_install_mbr',
                                         'os_install_uefi_set',
                                         'os_install_kernel_scheduler')),
@@ -134,6 +134,7 @@ class Wsdl(WsdlBase):
             'title': __("Flash Install"),
             'image': ('drive-removable-media-usb-pendrive,'
                       'drive-removable-media-usb,media-flash'),
+            'command': 'cl-install-flash',
             'gui': True,
             'rights': ['install'],
             'logic': {'Install': install.Install},
@@ -146,10 +147,12 @@ class Wsdl(WsdlBase):
                         'cl_dispatch_conf': 'usenew'},
             'groups': [
                 lambda group: group(_("Flash install"),
-                                    normal=('os_install_disk_single',
-                                            'cl_image_filename'),
-                                    expert=('os_location_data',),
-                                    next_label=_("Perform"))]},
+                                    normal=('cl_image_filename',
+                                            'os_install_disk_single',
+                                            'os_install_format_single_set'),
+                                    next_label=_("Perform"))],
+            'brief': {'next': __("Perform"),
+                      'name': __("Start installing")}},
         # PXE установка
         {
             'method_name': "install_pxe",
